==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__24AttributeInfo.h <==
// final class gnu.xml.pipeline.ValidationConsumer$AttributeInfo

// class file dependencies
// @dep_class d650d3352fd4442f gnu_xml_pipeline_ValidationConsumer__24AttributeInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object *);
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$method$_init$6cdc89487d7d5e9b(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object *);

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*mode;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24AttributeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__24AttributeInfo.h <==
// final class gnu.xml.pipeline.ValidationConsumer$AttributeInfo

// class file dependencies
// @dep_class d650d3352fd4442f gnu_xml_pipeline_ValidationConsumer__24AttributeInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$method$_init$6cdc89487d7d5e9b(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vmethods	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs {
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*mode;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_refs	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24AttributeInfo;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24AttributeInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24AttributeInfo_H_ */
